llama_chat_builtin_templates: List built-in chat templates

View source: R/llama.R

llama_chat_builtin_templatesR Documentation

List built-in chat templates

Description

Returns a character vector of all chat template names supported by llama.cpp.

Usage

llama_chat_builtin_templates()

Value

A character vector of built-in template names.

Examples

# See which chat template formats are supported out of the box
templates <- llama_chat_builtin_templates()
head(templates)

llamaR documentation built on May 28, 2026, 1:06 a.m.