llama_get_model: Get the model associated with a context

View source: R/llama.R

llama_get_modelR Documentation

Get the model associated with a context

Description

Returns the model handle that was used to create this context. The returned object is the same R external pointer that was passed to [llama_new_context] — no new allocation occurs.

Usage

llama_get_model(ctx)

Arguments

ctx

Context handle returned by [llama_new_context]

Value

A model handle (external pointer), equivalent to the original handle returned by [llama_load_model].


llamaR documentation built on May 28, 2026, 1:06 a.m.