llama_hf_cache_dir: Get the cache directory for downloaded models

View source: R/hf.R

llama_hf_cache_dirR Documentation

Get the cache directory for downloaded models

Description

Returns the path to the directory where models downloaded from Hugging Face are cached. The directory is created if it does not exist.

Usage

llama_hf_cache_dir()

Value

A character string containing the absolute path to the cache directory. The path follows the R user directory convention via R_user_dir.

Examples

llama_hf_cache_dir()

llamaR documentation built on May 28, 2026, 1:06 a.m.