| llama_chat_builtin_templates | R Documentation |
Returns a character vector of all chat template names supported by llama.cpp.
llama_chat_builtin_templates()
A character vector of built-in template names.
# See which chat template formats are supported out of the box
templates <- llama_chat_builtin_templates()
head(templates)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.