| llama_chat_template | R Documentation |
Returns the chat template string embedded in the model file, if any. Common templates include ChatML, Llama, Mistral, etc.
llama_chat_template(model, name = NULL)
model |
Model handle returned by [llama_load_model] |
name |
Optional template name (NULL for default) |
A character scalar with the chat template string, or NULL if
the model does not contain a built-in template.
## Not run:
model <- llama_load_model("llama-3.2-instruct.gguf")
tmpl <- llama_chat_template(model)
cat(tmpl)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.