| llama_get_model | R Documentation |
Returns the model handle that was used to create this context. The returned object is the same R external pointer that was passed to [llama_new_context] — no new allocation occurs.
llama_get_model(ctx)
ctx |
Context handle returned by [llama_new_context] |
A model handle (external pointer), equivalent to the original handle returned by [llama_load_model].
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.