| llama_hf_cache_dir | R Documentation |
Returns the path to the directory where models downloaded from Hugging Face are cached. The directory is created if it does not exist.
llama_hf_cache_dir()
A character string containing the absolute path to the cache
directory. The path follows the R user directory convention via
R_user_dir.
llama_hf_cache_dir()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.