| llama_hf_cache_info | R Documentation |
Lists all cached model files with their sizes and download metadata.
llama_hf_cache_info(cache_dir = NULL)
cache_dir |
Character or |
A data frame with columns:
Character. The Hugging Face repository identifier.
Character. The model file name.
Numeric. File size in bytes.
Character. Human-readable file size.
Character. Absolute path to the cached file.
Character. Timestamp of when the file was downloaded.
Returns an empty data frame with the same columns if the cache is empty.
llama_hf_cache_info()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.