| llama_memory_seq_pos_range | R Documentation |
Returns the minimum and maximum token positions for a given sequence in the KV cache.
llama_memory_seq_pos_range(ctx, seq_id)
ctx |
Context handle returned by [llama_new_context] |
seq_id |
Sequence ID |
A named integer vector with elements min and max.
## Not run:
range <- llama_memory_seq_pos_range(ctx, seq_id = 0L)
cat("Positions:", range["min"], "to", range["max"], "\n")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.