| llama_state_get_size | R Documentation |
Returns the number of bytes required to serialize the current context state (KV cache + sampling state). Use before allocating a buffer for raw state I/O.
llama_state_get_size(ctx)
ctx |
Context handle returned by [llama_new_context] |
A numeric scalar (size in bytes).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.